# Class for Linux-dependent actions (bootstrapping, etc)
#
# Copyright 2006-2007 Novell, Inc.
# Author: Charles Coffing <ccoffing@novell.com>
#
# This software may be freely redistributed under the terms of the GNU
# general public license.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import os
import glob

from log import log
from VMActions import VMActions
import caps

class VMLinux(VMActions):
    def getRuntimeImagesFromPath(self, root):
        """Returns a usable kernel and initrd pair found under 'root', or
        (None, None) if none are found."""
        if caps.is_pae_capable():
            exts = ['xenpae', 'xen']
        else:
            exts = ['xen']
        for ext in exts:
            for path in ('/boot/', '/'):
                kernel = path + 'vmlinuz-' + ext
                if os.path.exists(root + kernel):
                    # initrd is, strictly speaking, optional, but its
                    # extension must match the kernel, so stop searching.
                    initrd = None
                    if os.path.exists(root + path + 'initrd-' + ext):
                        initrd = path + 'initrd-' + ext
                    log.info("Found kernel '%s'" % (kernel,))
                    return (kernel, initrd)
                else:
                    log.debug("'%s' does not exist" % (kernel,))
        # Fall back to file-globbing (filename may include a version)
        for ext in exts:
            for path in ('/boot/', '/'):
                kernels = glob.glob('%s%svmlinuz*%s*' % (root, path, ext))
                initrds = glob.glob('%s%sinitrd*%s*' % (root, path, ext))
                if kernels and initrds:
                    kernel = kernels[0][len(root):]
                    initrd = initrds[0][len(root):]
                    log.info("Found kernel '%s'" % (kernel,))
                    return (kernel, initrd)
        return (None, None)

    def getInstallArgs(self, options):
        return self.getRuntimeArgs(options)

    def getRuntimeArgs(self, options):
        args = []
        if not options.full_virt:
            if options.graphics == 'none':
                args.append('xencons=tty')
        return ' '.join(args)
