# Temporarily mounts disk images
#
# Copyright 2006-2007 Novell, Inc.
# Author: Charles Coffing <ccoffing@novell.com>
#
# This software may be freely redistributed under the terms of the GNU
# general public license.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

import os
import tempfile

import msg
from log import log
from util import run

class TemporaryMount:
    def __init__(self, device):
        self.mountpoint = None
        self.device = device

    def mount(self, fstype=None, options=None):
        if self.mountpoint:
            self.unmount()
        mtpt = tempfile.mkdtemp()
        args = ['/bin/mount']
        if fstype:
            args += ['-t', fstype]
        if options:
            args += ['-o', options]
        args += [self.device, mtpt]
        log.debug("Mounting a disk:  %s" % str(args))
        try:
            run(args)
        except:
            os.rmdir(mtpt)
            raise
        self.mountpoint = mtpt
        return self.mountpoint

    def unmount(self):
        if not self.mountpoint:
            return
        args = ['/bin/umount', self.mountpoint]
        log.debug("Unmounting a disk:  %s" % str(args))
        run(args)
        os.rmdir(self.mountpoint)
        self.mountpoint = None

    def __del__(self):
        if self.mountpoint:
            try:
                self.unmount()
            except:
                pass

class TemporaryNFSMount(TemporaryMount):
    def __init__(self, server, path):
        TemporaryMount.__init__(self, '%s:%s' % (server, path))

    def mount(self):
        return TemporaryMount.mount(self, fstype='nfs')

class TemporarySMBMount(TemporaryMount):
    def __init__(self, server, path):
        TemporaryMount.__init__(self, '//%s/%s' % (server, path))

    def mount(self):
        return TemporaryMount.mount(self, fstype='smbfs')

class TemporaryLoopMount(TemporaryMount):
    def __init__(self, file):
        TemporaryMount.__init__(self, file)

    def mount(self, options='loop,ro'):
        return TemporaryMount.mount(self, options=options)
